@@ -225,6 +225,9 @@ aggr_inI1_outR1_common(struct msg_digest *md
 
     insert_state(st);	/* needs cookies, connection, and msgid (0) */
 
+    /* copy the quirks we might have accumulated */
+    copy_quirks(&st->quirks,&md->quirks);
+
     st->st_doi = ISAKMP_DOI_IPSEC;
     st->st_situation = SIT_IDENTITY_ONLY; /* We only support this */
 
@@ -794,6 +797,7 @@ aggr_outI1(int whack_sock,
 	   , enum crypto_importance importance)
 {
     struct state *st;
+    struct spd_route *sr;
 
     /* set up new state */
     cur_state = st = new_state();
@@ -810,6 +814,17 @@ aggr_outI1(int whack_sock,
 
     get_cookie(TRUE, st->st_icookie, COOKIE_SIZE, &c->spd.that.host_addr);
 
+    st->st_import = importance;
+
+    for(sr=&c->spd; sr!=NULL; sr=sr->next) {
+	if(sr->this.xauth_client) {
+	    if(sr->this.xauth_name) {
+		strncpy(st->st_xauth_username, sr->this.xauth_name, sizeof(st->st_xauth_username));
+		break;
+	    }
+	}
+    }
+
     insert_state(st);	/* needs cookies, connection, and msgid (0) */
 
     if(init_am_st_oakley(st, policy) == FALSE) {
@@ -844,7 +859,7 @@ aggr_outI1(int whack_sock,
 	if (!st->st_sec_in_use) {
 	    ke->ke_pcrc.pcrc_func = aggr_outI1_continue;
 	    e = build_ke(&ke->ke_pcrc, st, st->st_oakley.group, importance);
-	    if(e != STF_SUSPEND) {
+	    if(e != STF_SUSPEND && e != STF_INLINE) {
 	      loglog(RC_CRYPTOFAILED, "system too busy");
 	      delete_state(st);
 	    }
