@@ -191,6 +191,8 @@ help(void)
 	    " \\\n   "
 	    " [--debug-natt]"
 	    " [--debug-x509]"
+	    " [--debug-oppo]"
+	    " [--debug-oppoinfo]"
 	    " \\\n   "
 	    " [--debug-private]"
 	    "\n\n"
@@ -482,7 +484,7 @@ enum option_enums {
     DBGOPT_NATT,        /* same order as DBG_* */
     DBGOPT_X509,        /* same order as DBG_* */
     DBGOPT_DPD,         /* same order as DBG_* */
-    DBGOPT_RES14,
+    DBGOPT_OPPOINFO,
     DBGOPT_RES15,
     DBGOPT_RES16,
     DBGOPT_RES17,
@@ -676,6 +678,7 @@ static const struct option long_opts[] = {
     { "debug-klips", no_argument, NULL, DBGOPT_KLIPS + OO },
     { "debug-dns", no_argument, NULL, DBGOPT_DNS + OO },
     { "debug-oppo", no_argument, NULL, DBGOPT_OPPO + OO },
+    { "debug-oppoinfo", no_argument, NULL, DBGOPT_OPPOINFO + OO },
     { "debug-controlmore", no_argument, NULL, DBGOPT_CONTROLMORE + OO },
     { "debug-pfkey",   no_argument, NULL, DBGOPT_PFKEY + OO },
     { "debug-nattraversal", no_argument, NULL, DBGOPT_NATT + OO },
@@ -1568,6 +1571,7 @@ main(int argc, char **argv)
 	case DBGOPT_NATT:       /* --debug-pfkey */
 	case DBGOPT_X509:       /* --debug-pfkey */
 	case DBGOPT_DPD:        /* --debug-dpd */
+	case DBGOPT_OPPOINFO:	/* --debug-oppoinfo */
 	case DBGOPT_PRIVATE:	/* --debug-private */
 	case DBGOPT_IMPAIR_DELAY_ADNS_KEY_ANSWER:	/* --impair-delay-adns-key-answer */
 	case DBGOPT_IMPAIR_DELAY_ADNS_TXT_ANSWER:	/* --impair-delay-adns-txt-answer */
